==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "Edit comment" : "Wysig kommentaar",
    "Delete comment" : "Skrap kommentaar",
    "New comment …" : "Nuwe kommentaar…",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with ID {id}" : "’n Fout het voorgekom toe kommentaar met id {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is",
    "_%n unread comment_::_%n unread comments_" : ["%n ongeleesde kommentaar","%n ongeleeste kommentare"],
    "Comment" : "Kommentaar",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Jy was genoem op \"%s\", in die kommentaar van 'n gebruiker wat intussen geskrap is.",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Jy was genoem op “{lêer}”, in die kommentaar van 'n gebruiker wat intussen geskrap is.",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s het u in ’n kommentaar op “%2$s” genoem",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem",
    "Unknown user" : "Onbekende gebruiker",
    "A (now) deleted user mentioned you in a comment on “%s”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “%s” genoem",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “{lêer}” genoem"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Wysig kommentaar",
    "Delete comment" : "Skrap kommentaar",
    "New comment …" : "Nuwe kommentaar…",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "Comments" : "Kommentare",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with ID {id}" : "’n Fout het voorgekom toe kommentaar met id {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met id {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is",
    "_%n unread comment_::_%n unread comments_" : ["%n ongeleesde kommentaar","%n ongeleeste kommentare"],
    "Comment" : "Kommentaar",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Jy was genoem op “{lêer}”, in die kommentaar van 'n gebruiker wat intussen geskrap is.",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem",
    "Unknown user" : "Onbekende gebruiker",
    "A (now) deleted user mentioned you in a comment on “%s”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “%s” genoem",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "’n (Nou) geskrapte gebruiker het u in ’n kommentaar op “{lêer}” genoem",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s het u in ’n kommentaar op “%2$s” genoem",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Jy was genoem op \"%s\", in die kommentaar van 'n gebruiker wat intussen geskrap is."
},
"nplurals=2; plural=(n != 1);");
